import React, { FC } from 'react';
import { Grid, Typography } from '@material-ui/core';
import AddIcon from '@material-ui/icons/Add';
import Fab from '@material-ui/core/Fab';
import { NavBar } from 'components/Dashboard/HomePage/NavBar';
import { reservationPageStyle } from './ReservationPage.style';
import { ReservationDialog } from './ReservationDialog';
import { ReservationList } from './ReservationList/ReservationList';
import { ReservationsListByWeek } from './ReservationList/ReservationsListByWeek';
import { ReservationPageHeader } from './ReservationPageHeader';

export const ReservationPage: FC = () => {
  const classes = reservationPageStyle();

  const [isOpen, setIsOpen] = React.useState<boolean>(false);

  const handleOpen = (): void => {
    setIsOpen(true);
  };

  const handleClose = (): void => {
    setIsOpen(false);
  };

  return (
    <div data-testid="Reservation">
      <Grid container direction="column" className={classes.paddingBottom}>
        <ReservationPageHeader />
        <ReservationDialog handleClose={handleClose} isOpen={isOpen} />

        <Fab
          color="primary"
          size="large"
          className={classes.fab}
          onClick={handleOpen}
          aria-label="Add New Reservations"
        >
          <AddIcon className={classes.extendedIcon} />
        </Fab>

        <Grid item container className={classes.paddingTop}>
          <Grid item xs={1} lg={2} />
          <Grid item xs={10} lg={8}>
            <Typography variant="h3">Your Next Reservations</Typography>
          </Grid>
          <Grid item xs={1} lg={2} />

          <Grid item xs={1} lg={2} />
          <Grid item xs={10} lg={8}>
            <ReservationsListByWeek />
          </Grid>
          <Grid item xs={1} lg={2} />
        </Grid>
      </Grid>
    </div>
  );
};
